package
Version:
v0.13.0
Opens a new window with list of versions in this module.
Published: Jun 9, 2026
License: Apache-2.0
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Catch recovers from a fault.Panic and assigns it to the provided error pointer.
It re-panics if the recovered value is not a fault.Panic.
func Fail(format string, args ...interface{})
Fail triggers a panic with a formatted message and a fresh stack trace.
Panic wraps an error with the stack trace captured at the moment of failure.
Error implements the error interface, combining the message and stack.
Unwrap allows standard library errors.Is/As to work.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.